* Purpose: Create Brief Implicit Association Test (BIAT) summary variables.
* Source data: ANES 2010 Panel Study, SPSS Portable (por) file.
* Parts 1 and 2 of this program were provided to ANES by Tony Greenwald. 

* Part 1 organizes IAT trials data into 84 datasets, one for each trial.
* Part 2 aggregates trials data and computes summary scores for the brief IAT.
* Part 3 corrects errors in 13 problematic cases, names and labels variabes, and produces the final data file.


** PART 1.
** PART 1.
** Create 84 trials datasets.

CD "C:\Documents and Settings\Matthew DeBell\Desktop\sync\ANES\Panel\Data\IAT setup" .

IMPORT  FILE= 'anes2008_2009panel.por' .
DATASET NAME DataSet1 WINDOW=FRONT.

* Keep subject ID variable, wave completion flags, and all IAT variables .

DELETE VARIABLES  cd1 TO w19zh2, w20invit TO w20n6 .

*Fix numbering so 588 IAT variables are named from iat_Minus_1 to iat_566 .
RENAME VARIABLES w19iatbl=w19iat_Minus_1 w19iat_1=w19iat_0 w19iat_2=w19iat_1 w19iattr=w19iat_2 .
*Every 7th variable starting with: 
* w19iat_Minus_1is a block number 
* w19iat_0 is a is a block trial count 
* w19iat_1 is a is a block pairing code
* w19iat_2 is a is a trial number 
* w19iat_3 is a is a stimulus code
* w19iat_4 is a is a latency
* w19iat_5 is a is an error code (0=correct, 1=error) .

*Need to reformat stimulus code variables to standard length .
*To change the length of a string variable, declare a new variable of the desired length with the STRING command 
 and then use COMPUTE to copy values from the existing string into the new variable.
STRING s59, s115, s171, s227, s283, s339, s451, s563 (A10) .
COMPUTE s59 = w19ia_59 .
COMPUTE s115 = w19i_115 .
COMPUTE s171 = w19i_171 .
COMPUTE s227 = w19i_227 .
COMPUTE s283 = w19i_283 .
COMPUTE s339 = w19i_339 .
COMPUTE s451 = w19i_451 .
COMPUTE s563 = w19i_563 .
EXECUTE .

*Saving this file will make the next steps go much faster .
SAVE OUTFILE='Large_data_set.sav' .

* Need to convert the 588 variables into 84 sets of 7 variables .
SAVE OUTFILE= 'Trial01.sav' / KEEP = caseid w19iat_Minus_1 TO w19iat_5
 / RENAME (w19iat_Minus_1 TO w19iat_5 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial02.sav' / KEEP = caseid w19iat_6 TO w19ia_12 / RENAME (w19iat_6 TO w19ia_12 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial03.sav' / KEEP = caseid w19ia_13 TO w19ia_19 / RENAME (w19ia_13 TO w19ia_19 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial04.sav' / KEEP = caseid w19ia_20 TO w19ia_26 / RENAME (w19ia_20 TO w19ia_26 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial05.sav' / KEEP = caseid w19ia_27 TO w19ia_33 / RENAME (w19ia_27 TO w19ia_33 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial06.sav' / KEEP = caseid w19ia_34 TO w19ia_40 / RENAME (w19ia_34 TO w19ia_40 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial07.sav' / KEEP = caseid w19ia_41 TO w19ia_47 / RENAME (w19ia_41 TO w19ia_47 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial08.sav' / KEEP = caseid w19ia_48 TO w19ia_54 / RENAME (w19ia_48 TO w19ia_54 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial09.sav' / KEEP = caseid w19ia_55 TO w19ia_58 s59 w19ia_60 w19ia_61 / RENAME (w19ia_55 TO w19ia_58 s59 w19ia_60 w19ia_61 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial10.sav' / KEEP = caseid w19ia_62 TO w19ia_68 / RENAME (w19ia_62 TO w19ia_68 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial11.sav' / KEEP = caseid w19ia_69 TO w19ia_75 / RENAME (w19ia_69 TO w19ia_75 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial12.sav' / KEEP = caseid w19ia_76 TO w19ia_82 / RENAME (w19ia_76 TO w19ia_82 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial13.sav' / KEEP = caseid w19ia_83 TO w19ia_89 / RENAME (w19ia_83 TO w19ia_89 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial14.sav' / KEEP = caseid w19ia_90 TO w19ia_96 / RENAME (w19ia_90 TO w19ia_96 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial15.sav' / KEEP = caseid w19ia_97 TO w19i_103 / RENAME (w19ia_97 TO w19i_103 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial16.sav' / KEEP = caseid w19i_104 TO w19i_110 / RENAME (w19i_104 TO w19i_110 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial17.sav' / KEEP = caseid w19i_111 TO w19i_114 s115 w19i_116 w19i_117 / RENAME (w19i_111 TO w19i_114 s115 w19i_116 w19i_117 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial18.sav' / KEEP = caseid w19i_118 TO w19i_124 / RENAME (w19i_118 TO w19i_124 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial19.sav' / KEEP = caseid w19i_125 TO w19i_131 / RENAME (w19i_125 TO w19i_131 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial20.sav' / KEEP = caseid w19i_132 TO w19i_138 / RENAME (w19i_132 TO w19i_138 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial21.sav' / KEEP = caseid w19i_139 TO w19i_145 / RENAME (w19i_139 TO w19i_145 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial22.sav' / KEEP = caseid w19i_146 TO w19i_152 / RENAME (w19i_146 TO w19i_152 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial23.sav' / KEEP = caseid w19i_153 TO w19i_159 / RENAME (w19i_153 TO w19i_159 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial24.sav' / KEEP = caseid w19i_160 TO w19i_166 / RENAME (w19i_160 TO w19i_166 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial25.sav' / KEEP = caseid w19i_167 TO w19i_170 s171 w19i_172 w19i_173 / RENAME (w19i_167 TO w19i_170 s171 w19i_172 w19i_173 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial26.sav' / KEEP = caseid w19i_174 TO w19i_180 / RENAME (w19i_174 TO w19i_180 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial27.sav' / KEEP = caseid w19i_181 TO w19i_187 / RENAME (w19i_181 TO w19i_187 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial28.sav' / KEEP = caseid w19i_188 TO w19i_194 / RENAME (w19i_188 TO w19i_194 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial29.sav' / KEEP = caseid w19i_195 TO w19i_201 / RENAME (w19i_195 TO w19i_201 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial30.sav' / KEEP = caseid w19i_202 TO w19i_208 / RENAME (w19i_202 TO w19i_208 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial31.sav' / KEEP = caseid w19i_209 TO w19i_215 / RENAME (w19i_209 TO w19i_215 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial32.sav' / KEEP = caseid w19i_216 TO w19i_222 / RENAME (w19i_216 TO w19i_222 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial33.sav' / KEEP = caseid w19i_223 TO w19i_226 s227 w19i_228 w19i_229 / RENAME (w19i_223 TO w19i_226 s227 w19i_228 w19i_229 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial34.sav' / KEEP = caseid w19i_230 TO w19i_236 / RENAME (w19i_230 TO w19i_236 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial35.sav' / KEEP = caseid w19i_237 TO w19i_243 / RENAME (w19i_237 TO w19i_243 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial36.sav' / KEEP = caseid w19i_244 TO w19i_250 / RENAME (w19i_244 TO w19i_250 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial37.sav' / KEEP = caseid w19i_251 TO w19i_257 / RENAME (w19i_251 TO w19i_257 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial38.sav' / KEEP = caseid w19i_258 TO w19i_264 / RENAME (w19i_258 TO w19i_264 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial39.sav' / KEEP = caseid w19i_265 TO w19i_271 / RENAME (w19i_265 TO w19i_271 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial40.sav' / KEEP = caseid w19i_272 TO w19i_278 / RENAME (w19i_272 TO w19i_278 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial41.sav' / KEEP = caseid w19i_279 TO w19i_282 s283 w19i_284 w19i_285 / RENAME (w19i_279 TO w19i_282 s283 w19i_284 w19i_285 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial42.sav' / KEEP = caseid w19i_286 TO w19i_292 / RENAME (w19i_286 TO w19i_292 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial43.sav' / KEEP = caseid w19i_293 TO w19i_299 / RENAME (w19i_293 TO w19i_299 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial44.sav' / KEEP = caseid w19i_300 TO w19i_306 / RENAME (w19i_300 TO w19i_306 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial45.sav' / KEEP = caseid w19i_307 TO w19i_313 / RENAME (w19i_307 TO w19i_313 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial46.sav' / KEEP = caseid w19i_314 TO w19i_320 / RENAME (w19i_314 TO w19i_320 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial47.sav' / KEEP = caseid w19i_321 TO w19i_327 / RENAME (w19i_321 TO w19i_327 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial48.sav' / KEEP = caseid w19i_328 TO w19i_334 / RENAME (w19i_328 TO w19i_334 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial49.sav' / KEEP = caseid w19i_335 TO w19i_338 s339 w19i_340 w19i_341 / RENAME (w19i_335 TO w19i_338 s339 w19i_340 w19i_341 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial50.sav' / KEEP = caseid w19i_342 TO w19i_348 / RENAME (w19i_342 TO w19i_348 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial51.sav' / KEEP = caseid w19i_349 TO w19i_355 / RENAME (w19i_349 TO w19i_355 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial52.sav' / KEEP = caseid w19i_356 TO w19i_362 / RENAME (w19i_356 TO w19i_362 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial53.sav' / KEEP = caseid w19i_363 TO w19i_369 / RENAME (w19i_363 TO w19i_369 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial54.sav' / KEEP = caseid w19i_370 TO w19i_376 / RENAME (w19i_370 TO w19i_376 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial55.sav' / KEEP = caseid w19i_377 TO w19i_383 / RENAME (w19i_377 TO w19i_383 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial56.sav' / KEEP = caseid w19i_384 TO w19i_390 / RENAME (w19i_384 TO w19i_390 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial57.sav' / KEEP = caseid w19i_391 TO w19i_397 / RENAME (w19i_391 TO w19i_397 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial58.sav' / KEEP = caseid w19i_398 TO w19i_404 / RENAME (w19i_398 TO w19i_404 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial59.sav' / KEEP = caseid w19i_405 TO w19i_411 / RENAME (w19i_405 TO w19i_411 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial60.sav' / KEEP = caseid w19i_412 TO w19i_418 / RENAME (w19i_412 TO w19i_418 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial61.sav' / KEEP = caseid w19i_419 TO w19i_425 / RENAME (w19i_419 TO w19i_425 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial62.sav' / KEEP = caseid w19i_426 TO w19i_432 / RENAME (w19i_426 TO w19i_432 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial63.sav' / KEEP = caseid w19i_433 TO w19i_439 / RENAME (w19i_433 TO w19i_439 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial64.sav' / KEEP = caseid w19i_440 TO w19i_446 / RENAME (w19i_440 TO w19i_446 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial65.sav' / KEEP = caseid w19i_447 TO w19i_450 s451 w19i_452 w19i_453 / RENAME (w19i_447 TO w19i_450 s451 w19i_452 w19i_453 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial66.sav' / KEEP = caseid w19i_454 TO w19i_460 / RENAME (w19i_454 TO w19i_460 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial67.sav' / KEEP = caseid w19i_461 TO w19i_467 / RENAME (w19i_461 TO w19i_467 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial68.sav' / KEEP = caseid w19i_468 TO w19i_474 / RENAME (w19i_468 TO w19i_474 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial69.sav' / KEEP = caseid w19i_475 TO w19i_481 / RENAME (w19i_475 TO w19i_481 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial70.sav' / KEEP = caseid w19i_482 TO w19i_488 / RENAME (w19i_482 TO w19i_488 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial71.sav' / KEEP = caseid w19i_489 TO w19i_495 / RENAME (w19i_489 TO w19i_495 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial72.sav' / KEEP = caseid w19i_496 TO w19i_502 / RENAME (w19i_496 TO w19i_502 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial73.sav' / KEEP = caseid w19i_503 TO w19i_509 / RENAME (w19i_503 TO w19i_509 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial74.sav' / KEEP = caseid w19i_510 TO w19i_516 / RENAME (w19i_510 TO w19i_516 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial75.sav' / KEEP = caseid w19i_517 TO w19i_523 / RENAME (w19i_517 TO w19i_523 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial76.sav' / KEEP = caseid w19i_524 TO w19i_530 / RENAME (w19i_524 TO w19i_530 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial77.sav' / KEEP = caseid w19i_531 TO w19i_537 / RENAME (w19i_531 TO w19i_537 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial78.sav' / KEEP = caseid w19i_538 TO w19i_544 / RENAME (w19i_538 TO w19i_544 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial79.sav' / KEEP = caseid w19i_545 TO w19i_551 / RENAME (w19i_545 TO w19i_551 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial80.sav' / KEEP = caseid w19i_552 TO w19i_558 / RENAME (w19i_552 TO w19i_558 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial81.sav' / KEEP = caseid w19i_559 TO w19i_562 s563 w19i_564 w19i_565 / RENAME (w19i_559 TO w19i_562 s563 w19i_564 w19i_565 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial82.sav' / KEEP = caseid w19i_566 TO w19i_572 / RENAME (w19i_566 TO w19i_572 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial83.sav' / KEEP = caseid w19i_573 TO w19i_579 / RENAME (w19i_573 TO w19i_579 = block trial_count pairing_code trial stimulus RT error) .
SAVE OUTFILE= 'Trial84.sav' / KEEP = caseid w19i_580 TO w19i_586 / RENAME (w19i_580 TO w19i_586 = block trial_count pairing_code trial stimulus RT error) .

GET FILE = "Trial01.sav" .
ADD FILES FILE = * / FILE = "Trial02.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial03.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial04.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial05.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial06.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial07.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial08.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial09.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial10.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial11.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial12.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial13.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial14.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial15.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial16.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial17.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial18.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial19.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial20.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial21.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial22.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial23.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial24.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial25.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial26.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial27.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial28.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial29.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial30.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial31.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial32.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial33.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial34.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial35.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial36.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial37.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial38.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial39.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial40.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial41.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial42.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial43.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial44.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial45.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial46.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial47.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial48.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial49.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial50.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial51.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial52.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial53.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial54.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial55.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial56.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial57.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial58.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial59.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial60.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial61.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial62.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial63.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial64.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial65.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial66.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial67.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial68.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial69.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial70.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial71.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial72.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial73.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial74.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial75.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial76.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial77.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial78.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial79.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial80.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial81.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial82.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial83.sav" .  
EXECUTE .
ADD FILES FILE = * / FILE = "Trial84.sav" .  
EXECUTE .

FREQUENCIES  block trial_count pairing_code trial stimulus error .
CROSSTABS trial BY stimulus .

SAVE OUTFILE = "Trials_1-84.sav" .




***  PART 2 .
***  PART 2. 
***  Aggregate trials data and compute D scores. 

GET  FILE = "Trials_1-84.sav" .

* Variable names in this file: 
   caseid block trial_count pairing_code trial stimulus RT error .

SORT CASES BY caseid block trial .

COMPUTE casenum = $casenum .
EXECUTE .
AGGREGATE OUTFILE = * MODE = ADDVARIABLES / BREAK = caseid / N_trials = N(trial) / first_casenum=FIRST(casenum).
FREQUENCIES N_trials .
* 0.8% of cases have 14, 28, or 56 trials; 51.7% have the full 84; the remaining 47.5% have no IAT data.
* Note that some of those with 84 trials don't actually have the desired no. of trials .

COMPUTE filter$=(N_trials > 0 AND N_trials ne 84 AND ($casenum=first_casenum)) .
FILTER BY filter$ .
LIST VARIABLES caseid N_trials .
FILTER OFF .

SELECT IF (N_trials = 84) .

VARIABLE LABELS 
   caseid "caseid"
 / block "block number"
 / pairing_code "block code"
 / stimulus "stimulus item"
 / RT "latency"
 / error "error"
 / trial "trial number" 
 / trial_count "no. of trials in block" .

DESCRIPTIVES ALL .

VALUE LABELS  error 1 "error" 0 "correct" .

CROSSTABS block BY pairing_code .
CROSSTABS block BY trial_count .
CROSSTABS trial BY error .

IF (pairing_code = "BlackPeople-Bad_WhitePeople-Good") pairing=1 .
IF (pairing_code = "WhitePeople-Bad_BlackPeople-Good") pairing=2 .
EXECUTE .

VARIABLE LABELS  pairing "focal categories" .
VALUE LABELS pairing  1 'White+good' 2 'Black+good' .
FREQUENCIES pairing .
 
*Code the blockorder variable. 
IF (pairing_code = "BlackPeople-Bad_WhitePeople-Good" & block=1) blockorder=1 .
IF (pairing_code = "BlackPeople-Bad_WhitePeople-Good" & block=2) blockorder=2 .
IF (pairing_code = "BlackPeople-Bad_WhitePeople-Good" & block=3) blockorder=1 .
IF (pairing_code = "BlackPeople-Bad_WhitePeople-Good" & block=4) blockorder=2 .
IF (pairing_code = "WhitePeople-Bad_BlackPeople-Good" & block=1) blockorder=2 .
IF (pairing_code = "WhitePeople-Bad_BlackPeople-Good" & block=2) blockorder=1 .
IF (pairing_code = "WhitePeople-Bad_BlackPeople-Good" & block=3) blockorder=2 .
IF (pairing_code = "WhitePeople-Bad_BlackPeople-Good" & block=4) blockorder=1 .

VARIABLE LABELS blockorder "order of combined tasks" .
** block_order 1 is white-good first, 2 is black-good first ** .
VALUE LABELS blockorder 1 'white+good first' 2 'black+good first' .
FREQUENCIES blockorder .

*Identify test variable to indicate 1st or 2nd block of each pairing .
IF (block=1 | block=2 ) test=0 .
IF (block=3 | block=4 ) test=1 .
VARIABLE LABELS  test "combined task block" .
VALUE LABELS test 0 'practice' 1 'post-practice' .
FREQUENCIES test .

*High scores = greater assn of White than Black with pleasant .

DESCRIPTIVES ALL . 

****************************************************************** .
**** STEP 2: COMPUTE CRITERIA FOR POSSIBLE caseid DELETION ****** .
****************************************************************** .

COMPUTE filter$ = (block=1 OR block=2) .
FILTER BY filter$ .
CROSSTABS trial BY stimulus .
FILTER OFF .

COMPUTE filter$ = (block=3 OR block=4) .
FILTER BY filter$ .
CROSSTABS trial BY stimulus .
FILTER OFF .

*First drop trials 1&2 in Blocks 1&2, and trials 1-4 in Blocks 3&4 .
SELECT IF ((block <= 2 & trial >= 3) OR (block >= 3 & trial >= 5)) .
FORMATS filter$ test blockorder pairing (F1.0) . 
DESCRIPTIVES ALL . 

*Check for other problems .
AGGREGATE OUTFILE = * MODE = ADDVARIABLES OVERWRITE = YES / BREAK = caseid / N_trials = N(trial) .
AGGREGATE OUTFILE = * MODE = ADDVARIABLES OVERWRITE = YES / BREAK = caseid block / block_N = N(trial) .
FREQUENCIES N_trials .

*Check on subjects have fewer than 72 total trials remaining .
COMPUTE filter$ = (N_trials < 72) .
FILTER BY filter$ .
CROSSTABS trial BY stimulus .
CROSSTABS trial BY trial_count .
FREQUENCIES caseid .
FILTER OFF .

*Explore for other aberrant cases .
FREQUENCIES block_N .
CROSSTABS block BY block_N .
COMPUTE filter$ = (trial=5) & ((block=1 & block_N ne 12) OR (block=2 & block_N ne 12) OR (block=3 & block_N ne 24) OR (block=4 & block_N ne 24)) .
FILTER BY filter$ .
LIST VARIABLES caseid block block_N .
FREQUENCIES caseid .
FILTER OFF .

*Delete any cases with irregularities .

*After any deletions, check that remaining cases are OK .
COMPUTE filter$ = (trial=5) .
FILTER BY filter$ .
FREQUENCIES block block_N .
FILTER OFF .

*The above shows that the remaining cases appear OK .

*Mark trials with latency < 300 ms (for possible caseid discard) .
COMPUTE flag_300 = 0 .
IF (RT < 300) flag_300 = 1 .
*Mark trials with latency < 400 ms (to provide a count of these) .
COMPUTE flag_400 = 0 .
IF (RT < 400) flag_400 = 1 .
*Mark trials with latency > 2000 ms (to provide a count of these) .
COMPUTE flag_2K = 0 .
IF (RT GT 2000) flag_2K = 1 .
*Mark trials with latency > 3000 ms (to provide a count of these) .
COMPUTE flag_3K = 0 .
IF (RT GT 3000) flag_3K = 1 .
*Mark trials with latency > 4000 ms (to provide a count of these) .
COMPUTE flag_4K = 0 .
IF (RT GT 10000) flag_4K = 1 .

*Following line checks frequencies of fast & slow responses & errors .
FREQUENCIES flag_300 flag_400 flag_2K flag_3K flag_4K error .

*Save criteria for potential use in caseid discards in file named 'selection_criteria.sav' .
AGGREGATE OUTFILE = 'selection_criteria.sav'
 / BREAK = caseid
 / pct_300 = PGT(flag_300,0) 
 / pct_400 = PGT(flag_400,0)
 / pct_2K = PGT(flag_2K,0)
 / pct_3K = PGT(flag_3K,0)
 / pct_4K = PGT(flag_4K,0)
 / aveltncy = MEAN (RT)
 / error_pct = PGT(error,0)
 / ntrials = N .

****************************************************************** .
********************* STEP 3: COMPUTE D-biep ********************* .
****************************************************************** .
*The following recoding commands are appropriate for Brief IATs .
*  Preferred strategy is to use 2000 ms as upper boundary, recoding more extreme values to that value .
IF (RT > 2000) RT = 2000 .

* Likewise, recode trials faster than 400 ms to 400 for RT .
IF (RT < 400) RT = 400 .
EXECUTE .

* The computation needs an "inclusive SD" (SD for all trials in blocks 1&2l another for 3&4) . 
*  This can be computed from the individual block means and SDs .
* The following aggregate command computes block mean RTs and SDs needed for the D measures.
AGGREGATE OUTFILE = *
 / BREAK = caseid block blockorder pairing test 
 / Mn_RT = MEAN(RT) / pct_error = PGT (error,0) / SD_RT = SD(RT) 
 / ntrials = N .

IF (pairing = 1) N1 = ntrials .
IF (pairing = 2) N2 = ntrials .
IF (pairing = 1) M1 = Mn_RT .
IF (pairing = 2) M2 = Mn_RT .
IF (pairing = 1) error1 = pct_error .
IF (pairing = 2) error2 = pct_error .
IF (pairing = 1) SD1 = SD_RT .
IF (pairing = 2) SD2 = SD_RT .
EXECUTE .

*This command gets all variables needed for each caseid onto two lines, one for blocks 1&2 (test=0), 
*  the other for blocks 3&4 (test=1) .
AGGREGATE OUTFILE = *
 / BREAK = caseid blockorder test 
 / M1 M2 error1 error2 N1 N2 SD1 SD2 =
  FIRST(M1 M2 error1 error2 N1 N2 SD1 SD2) .

*Create error % variables needed for subsequent reduction to a single line per caseid .
IF(test=0) error1_x = error1 .
IF(test=0) error2_x = error2 .
IF(test=1) error1_a = error1 .
IF(test=1) error2_a = error2 .
EXECUTE .

* Compute D_biep (= "D with built-in error penalty") separately for test=0 and test=1 .
COMPUTE D_biep_numerator = M2 - M1 .

*This is the formula to compute inclusive SD from component block means and SDs .
COMPUTE D_biep_denominator = SQRT( ( ((N1-1) * SD1**2 + (N2-1) * SD2**2)
                   + ((N1+N2) * ((M1-M2)**2) / 4) ) / (N1 + N2 - 1) ) .
EXECUTE .

IF (TEST=0) D_BIEP_x = D_biep_numerator / D_biep_denominator .
IF (TEST=1) D_BIEP_a = D_biep_numerator / D_biep_denominator .
*Errors of division by zero may be produced by above because if all trials in a block are recoded
* to the same value of 2000 msec because of very slow responding;
* This will produce a missing value for a D measure .

*These N variables needed for subsequent reduction to single line per caseid .
IF (TEST=0) Nx = N1+N2 .
IF (TEST=1) Na = N1+N2 .
DESCRIPTIVES ALL .

*Reduce to a single line  per caseid .
AGGREGATE OUTFILE = *
 / BREAK = caseid blockorder
 / D_biep_x D_biep_a error1_x error2_x error1_a error2_a Nx Na = FIRST
  (D_biep_x D_biep_a error1_x error2_x error1_a error2_a Nx Na ) .

*Compute unweighted combination of measures based on first and second blocks of combined tasks.
* !! Do this even though there are fewer trials in the first pair of blocks; the first pair of blocks has been found
*  to have as good or better validity than the 2nd pair, despite fewer trials (see Greenwald, Nosek, & Banaji, JPSP 2003) .

*This computes the overall D_biep measure (combining the separate measures from Blocks 1&2 and Blocks 3&4 .
COMPUTE D_biep = (D_biep_x + D_biep_a) / 2 .

*These lines compute average error rates for Blocks 1&2 and for Blocks 3&4 .
COMPUTE errorx = MEAN(error1_x, error2_x) .
COMPUTE errora = MEAN(error1_a, error2_a) .
EXECUTE .

VARIABLE LABELS
   Nx '# trials, practice'
 / Na '# trials, 1st combined blocks'
 / D_biep_x 'D - built-in error penalty (Blocks 1&2)' 
 / D_biep_a 'D - built-in error penalty (Blocks 3&4)' 
 / D_biep 'D - built-in error penalty (overall BIAT D measure)' 
 / errorx 'error % for Blocks 1 & 2'
 / errora 'error % for Blocks 3 & 4'  .

FORMATS  D_biep D_biep_x D_biep_a (F6.3) Nx Na (F4.0) errorx errora (F5.1) .

SORT CASES BY caseid .
SAVE OUTFILE = 'D_biep.measures.sav' / DROP = error1_x error2_x error1_a error2_a .

DESCRIPTIVES  ALL .

********************************************************************* .
**** STEP 4: COMBINE D MEASURES WITH SELECTION CRITERIA AND SAVE **** .
********************************************************************* .

*If desired, following commands can be used to combine and save all of the files .
MATCH FILES FILE = 'D_biep.measures.sav' / FILE = 'selection_criteria.sav' / BY caseid .
EXECUTE .

FREQUENCIES ntrials .
* All cases have 72 trials .

FORMATS aveltncy (F7.1) pct_300 pct_400 pct_2K pct_3K pct_4K error_pct (F6.1) caseid (F8.0) .

*Examine properties of discard criteria .
EXAMINE  aveltncy pct_300 pct_400 pct_2K pct_3K pct_4K error_pct .

*Labels for variables in selection_criteria.sav .
VARIABLE LABELS
   pct_300 '% latencies below 300 ms'
 / pct_400 '% latencies below 400 ms'
 / pct_2K '% latencies above 2,000 ms'
 / pct_3K '% latencies above 3,000 ms'
 / pct_4K '% latencies above 4,000 ms'
 / aveltncy 'Overall average latency (ms)'
 / error_pct 'Overall % errors' 
 / ntrials 'Total # of combined-task trials' .

*Note: No caseids have yet been discarded.  However, each record contains .
* several variables that might be used for discard .
* pct_300 = overall % of responses with latencies below 300 ms .
* error_pct = overall error % .
* pct_3K  = % latencies above 3,000 ms .
* pct_4K = % latencies above 4,000 ms .
* aveltncy = overall average latency .
* [Note that 'aveltncy' was computed _BEFORE_ recoding latencies above 2,000 ms to 2,000 ms] .

DESCRIPTIVES ALL .

*Compute potential filters to limit analyses to respondents who showed good cooperation with instructions.
COMPUTE filter0$ = (pct_300<10) & (pct_4K<5) .
COMPUTE filter1$ = ((filter0$=1) & (error_pct<35)) .
COMPUTE filter2$ = ((filter1$=1) & (aveltncy<2500)) .

VARIABLE LABELS 
  filter0$ "less than 10% responses faster than 300 ms; less than 5% slower than 4K ms)" 
  filter1$ "filter0$ criteria AND error rate below 35%"
  filter2$ "filter1$ criteria AND avg latency faster than 2500 ms" .
FREQUENCIES filter0$ filter1$ filter2$ .

RENAME VARIABLES
 (D_biep = Overall_IAT)
 (D_biep_x = IAT_Part_1)
 (D_biep_a = IAT_Part_2)
 (error_pct = pct_err_overall)
 (errorx = pct_err_Part_1)
 (errora = pct_err_Part_2) .

*All computations are done at this point; 
* remaining commands provide some data description 
*Reminder: These D measures were computed using an upper trial-latency boundary of 2000 ms.
MEANS Overall_IAT IAT_Part_1 IAT_Part_2  BY filter0$ filter1$ filter2$  .
MEANS pct_err_overall pct_err_Part_1 pct_err_Part_2 BY filter0$ filter1$ filter2$  .
MEANS pct_300 pct_400 pct_2K pct_3K pct_4K BY filter0$ filter1$ filter2$ .

CORRELATIONS Overall_IAT IAT_Part_1 IAT_Part_2 .
DESCRIPTIVES Overall_IAT IAT_Part_1 IAT_Part_2 aveltncy pct_2k pct_3k pct_4k pct_err_overall pct_300 .
*FREQUENCIES Overall_IAT IAT_Part_1 IAT_Part_2 aveltncy pct_2k pct_3k pct_4k pct_err_overall pct_300 / FORMAT = NOTABLE / HISTOGRAM .

FILTER BY filter0$ .
CORRELATIONS Overall_IAT IAT_Part_1 IAT_Part_2 .
DESCRIPTIVES Overall_IAT IAT_Part_1 IAT_Part_2 aveltncy pct_2k pct_3k pct_4k pct_err_overall pct_300 .
*FREQUENCIES Overall_IAT IAT_Part_1 IAT_Part_2 aveltncy pct_2k pct_3k pct_4k pct_err_overall pct_300 / FORMAT = NOTABLE / HISTOGRAM .
FILTER OFF .

FILTER BY filter1$ .
CORRELATIONS Overall_IAT IAT_Part_1 IAT_Part_2 .
DESCRIPTIVES Overall_IAT IAT_Part_1 IAT_Part_2 aveltncy pct_2k pct_3k pct_4k pct_err_overall pct_300 .
*FREQUENCIES Overall_IAT IAT_Part_1 IAT_Part_2 aveltncy pct_2k pct_3k pct_4k pct_err_overall pct_300 / FORMAT = NOTABLE / HISTOGRAM .
FILTER OFF .

FILTER BY filter2$ .
CORRELATIONS Overall_IAT IAT_Part_1 IAT_Part_2 .
DESCRIPTIVES Overall_IAT IAT_Part_1 IAT_Part_2 aveltncy pct_2k pct_3k pct_4k pct_err_overall pct_300 .
*FREQUENCIES Overall_IAT IAT_Part_1 IAT_Part_2 aveltncy pct_2k pct_3k pct_4k pct_err_overall pct_300 / FORMAT = NOTABLE / HISTOGRAM .
FILTER OFF .

*This will show how IAT scores were affected by order of doing the two combined tasks .
MEANS Overall_IAT BY blockorder .

SAVE OUTFILE = "ANES.race_IAT.1_line_per_caseid.sav"
 /KEEP = caseid ntrials blockorder Overall_IAT IAT_Part_1 IAT_Part_2
    pct_300 pct_400 pct_2K pct_3K pct_4K aveltncy pct_err_overall pct_err_Part_1 pct_err_Part_2 
    filter0$ filter1$ filter2$ .


* PART 3.
* PART 3.
* Create release file.

GET FILE = "ANES.race_IAT.1_line_per_caseid.sav".

rename variables ntrials = IAT_n .
rename variables blockorder = IAT_ord.
rename variables Overall_IAT = IAT_D.
rename variables IAT_Part_1 = IAT_D12.
rename variables IAT_Part_2 = IAT_D34.
rename variables pct_300 = IAT_300.
rename variables pct_400 = IAT_400.
rename variables pct_2K = IAT_2K.
rename variables pct_3K = IAT_3K.
rename variables pct_4K = IAT_4K.
rename variables aveltncy = IAT_time.
rename variables pct_err_overall = IAT_err.
rename variables pct_err_Part_1 = IAT_err1.
rename variables pct_err_Part_2 = IAT_err2.
rename variables filter0$ = IAT_f0.
rename variables filter1$ = IAT_f1.
rename variables filter2$ = IAT_f2.

var lab IAT_n 'IAT_n. IAT, Total # of combined-task trials'.
var lab IAT_ord 'IAT_ord. IAT, order of combined tasks'.
var lab IAT_D 'IAT_D. IAT OVERALL SUMMARY SCORE (D)'.
var lab IAT_D12 'IAT_D12. IAT D for blocks 1&2'.
var lab IAT_D34 'IAT_D34. IAT D for blocks 3&4)'.
var lab IAT_300 'IAT_300. IAT % latencies below 300 ms'.
var lab IAT_400 'IAT_400. IAT % latencies below 400 ms'.
var lab IAT_2K 'IAT_2K. IAT % latencies above 2,000 ms'.
var lab IAT_3K 'IAT_3K. IAT % latencies above 3,000 ms'.
var lab IAT_4K 'IAT_4K. IAT % latencies above 4,000 ms'.
var lab IAT_time 'IAT_time. IAT overall average latency, ms'.
var lab IAT_err 'IAT_err. IAT overall % errors'.
var lab IAT_err1 'IAT_err1. IAT error % for Blocks 1 & 2'.
var lab IAT_err2 'IAT_err1. IAT error % for Blocks 3 & 4'.
var lab IAT_f0 'IAT_f0. Filter, under 10% below 300 ms; under 5% below 4K ms'.
var lab IAT_f1 'IAT_f1. Filter, f0 criteria and error rate under 35%'.
var lab IAT_f2 'IAT_f2. Filter, f1 criteria and avg latency above 2500ms'.

* Fix D scores for 13 problem cases.
* There are 13 respondents for whom trial data for the IAT are incorrect due to a data processing error.
* Anthony Greenwald, who collaborated with ANES to implement the brief IAT on the Panel Study, reviewed 
*   the raw data and computed overall IAT D scores for these cases. 
* This section of code writes those values to the variable iat_d.
* Corrected raw IAT trials data for these 13 cases are not presently available from ANES. 

if caseid=3161 iat_d =   .595.
if caseid=5784 iat_d =   .443.
if caseid=7390 iat_d =  -.051.
if caseid=8056 iat_d =   .151.
if caseid=10960 iat_d = -.408.
if caseid=17520 iat_d =  .694.
if caseid=17881 iat_d =  .002.
if caseid=18837 iat_d =  .940.
if caseid=18901 iat_d =  .855.
if caseid=19118 iat_d =  .012.
if caseid=22043 iat_d =  .704.
if caseid=22547 iat_d = -.647.
if caseid=24175 iat_d =  .329.
exe.

EXPORT OUTFILE='ANES0809Panel_IAT.por' .

